shell32: Spelling fixes

Francois Gouget fgouget at free.fr
Sun May 29 05:41:31 CDT 2016


Signed-off-by: Francois Gouget <fgouget at free.fr>
---
 dlls/shell32/iconcache.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/shell32/iconcache.c b/dlls/shell32/iconcache.c
index 4549d5b..c3284a2 100644
--- a/dlls/shell32/iconcache.c
+++ b/dlls/shell32/iconcache.c
@@ -106,7 +106,7 @@ static int SIC_LoadOverlayIcon(int icon_idx);
  * SIC_OverlayShortcutImage			[internal]
  *
  * NOTES
  *  Creates a new icon as a copy of the passed-in icon, overlayed with a
  *  shortcut image. 
  */
 static HICON SIC_OverlayShortcutImage(HICON SourceIcon, BOOL large)
@@ -332,7 +332,7 @@ static INT SIC_LoadIcon (LPCWSTR sSourceFile, INT dwSourceIndex, DWORD dwFlags)
 	  }
 	  else
 	  {
-	    WARN("Failed to create shortcut overlayed icons\n");
+	    WARN("Failed to create shortcut overlaid icons\n");
 	    if (NULL != hiconLargeShortcut) DestroyIcon(hiconLargeShortcut);
 	    if (NULL != hiconSmallShortcut) DestroyIcon(hiconSmallShortcut);
 	    dwFlags &= ~ GIL_FORSHORTCUT;
@@ -106,7 +106,7 @@ static int SIC_LoadOverlayIcon(int icon_idx);
  *
  * NOTES
- *  Creates a new icon as a copy of the passed-in icon, overlayed with a
+ *  Creates a new icon as a copy of the passed-in icon, overlaid with a
  *  shortcut image. 
  */
-- 
2.8.1




More information about the wine-patches mailing list